@@ -5,8 +5,9 @@ import (
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
-	"github.com/batchcorp/plumber/tunnel"
-	"github.com/batchcorp/plumber/types"
+
+	"github.com/streamdal/plumber/tunnel"
+	"github.com/streamdal/plumber/types"
 )
 
 func (c *CDCPostgres) Tunnel(ctx context.Context, tunnelOpts *opts.TunnelOptions, tunnelSvc tunnel.ITunnel, errorCh chan<- *records.ErrorRecord) error {
