@@ -4,11 +4,13 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/pkg/errors"
 
+	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
+
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
-	"github.com/batchcorp/plumber/printer"
+
+	"github.com/streamdal/plumber/printer"
 )
 
 func (k *KubeMQ) DisplayMessage(cliOpts *opts.CLIOptions, msg *records.ReadRecord) error {
