@@ -7,9 +7,10 @@ import (
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/args"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
-	"github.com/batchcorp/plumber/backends/pulsar/pulsarfakes"
-	"github.com/batchcorp/plumber/types"
-	"github.com/batchcorp/plumber/validate"
+
+	"github.com/streamdal/plumber/backends/pulsar/pulsarfakes"
+	"github.com/streamdal/plumber/types"
+	"github.com/streamdal/plumber/validate"
 )
 
 var _ = Describe("Pulsar Backend", func() {
