@@ -16,14 +16,14 @@ import (
 
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 
-	"github.com/batchcorp/plumber/actions"
-	"github.com/batchcorp/plumber/config"
-	"github.com/batchcorp/plumber/kv"
-	"github.com/batchcorp/plumber/options"
-	"github.com/batchcorp/plumber/plumber"
-	"github.com/batchcorp/plumber/printer"
-	"github.com/batchcorp/plumber/prometheus"
-	"github.com/batchcorp/plumber/telemetry"
+	"github.com/streamdal/plumber/actions"
+	"github.com/streamdal/plumber/config"
+	"github.com/streamdal/plumber/kv"
+	"github.com/streamdal/plumber/options"
+	"github.com/streamdal/plumber/plumber"
+	"github.com/streamdal/plumber/printer"
+	"github.com/streamdal/plumber/prometheus"
+	"github.com/streamdal/plumber/telemetry"
 )
 
 var (
@@ -154,6 +154,10 @@ func main() {
 
 // readFromStdin reads data piped into stdin
 func readFromStdin(opts *opts.CLIOptions) {
+	if opts.Global.XAction != "write" {
+		return
+	}
+
 	info, err := os.Stdin.Stat()
 	if err != nil {
 		logrus.Fatal(err)
