@@ -10,7 +10,7 @@ import (
 	"github.com/batchcorp/collector-schemas/build/go/protos/records"
 	"github.com/batchcorp/collector-schemas/build/go/protos/services"
 
-	"github.com/batchcorp/plumber/backends/gcppubsub/types"
+	"github.com/streamdal/plumber/backends/gcppubsub/types"
 )
 
 func (r *Relay) handleGCP(ctx context.Context, conn *grpc.ClientConn, messages []interface{}) error {
