@@ -13,10 +13,10 @@ import (
 	"github.com/batchcorp/plumber-schemas/build/go/protos/opts"
 	"github.com/batchcorp/plumber-schemas/build/go/protos/records"
 
-	"github.com/batchcorp/plumber/backends"
-	"github.com/batchcorp/plumber/options"
-	"github.com/batchcorp/plumber/tunnel"
-	"github.com/batchcorp/plumber/util"
+	"github.com/streamdal/plumber/backends"
+	"github.com/streamdal/plumber/options"
+	"github.com/streamdal/plumber/tunnel"
+	"github.com/streamdal/plumber/util"
 )
 
 type Tunnel struct {
